"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const errors_1 = require("./errors");
function getConfig() {
    return __awaiter(this, void 0, void 0, function* () {
        const env = filterAndTypecastEnvs(process.env);
        if (!env.cardanoNodeConfigPath) {
            throw new errors_1.MissingConfig('CARDANO_NODE_CONFIG_PATH env not set');
        }
        if (!env.hasuraUri) {
            throw new errors_1.MissingConfig('HASURA_URI env not set');
        }
        return Object.assign(Object.assign({}, env), { allowIntrospection: (process.env.NODE_ENV === 'production' && env.allowIntrospection) ||
                (process.env.NODE_ENV !== 'production' && env.allowIntrospection !== false), allowedOrigins: env.allowedOrigins || true, apiPort: env.apiPort || 3100, cacheEnabled: env.cacheEnabled || false, loggerMinSeverity: env.loggerMinSeverity || 'info', listenAddress: env.listenAddress || '0.0.0.0', maxQueryComplexity: env.maxQueryComplexity, pollingInterval: {
                adaSupply: env.pollingInterval.adaSupply || 1000 * 60
            }, queryDepthLimit: env.queryDepthLimit || 10 });
    });
}
exports.getConfig = getConfig;
function filterAndTypecastEnvs(env) {
    const { ALLOW_INTROSPECTION, ALLOWED_ORIGINS, ALLOW_LIST_PATH, API_PORT, CACHE_ENABLED, CARDANO_NODE_CONFIG_PATH, HASURA_URI, LISTEN_ADDRESS, LOGGER_MIN_SEVERITY, MAX_QUERY_COMPLEXITY, OGMIOS_HOST, OGMIOS_PORT, POLLING_INTERVAL_ADA_SUPPLY, PROMETHEUS_METRICS, QUERY_DEPTH_LIMIT, TRACING } = env;
    return {
        allowIntrospection: ALLOW_INTROSPECTION === 'true',
        allowedOrigins: ALLOWED_ORIGINS,
        allowListPath: ALLOW_LIST_PATH,
        apiPort: Number(API_PORT),
        cacheEnabled: CACHE_ENABLED === 'true',
        cardanoNodeConfigPath: CARDANO_NODE_CONFIG_PATH,
        hasuraUri: HASURA_URI,
        listenAddress: LISTEN_ADDRESS,
        loggerMinSeverity: LOGGER_MIN_SEVERITY,
        maxQueryComplexity: Number(MAX_QUERY_COMPLEXITY),
        ogmios: {
            host: OGMIOS_HOST,
            port: OGMIOS_PORT ? Number(OGMIOS_PORT) : undefined
        },
        pollingInterval: {
            adaSupply: Number(POLLING_INTERVAL_ADA_SUPPLY)
        },
        prometheusMetrics: PROMETHEUS_METRICS === 'true',
        queryDepthLimit: Number(QUERY_DEPTH_LIMIT),
        tracing: TRACING === 'true'
    };
}
//# sourceMappingURL=config.js.map